@@ -1,10 +1,9 @@
 package Linux::Info::Compilation;
+
 use strict;
 use warnings;
 use Carp qw(croak);
 
-our $VERSION = '0.10'; # VERSION
-
 =head1 NAME
 
 Linux::Info::Compilation - Statistics compilation.
@@ -212,12 +211,12 @@ This software is copyright (c) 2015 of Alceu Rodrigues de Freitas Junior, E<lt>a
 
 This file is part of Linux Info project.
 
-Linux-Info is free software: you can redistribute it and/or modify
+Linux Info is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
-Linux-Info is distributed in the hope that it will be useful,
+Linux Info is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
@@ -232,7 +231,6 @@ BEGIN {
     foreach
       my $stat (qw/sysinfo procstats memstats sockstats loadavg filestats/)
     {
-## no critic
         no strict 'refs';
         *{$stat} = sub {
             use strict 'refs';
@@ -243,12 +241,10 @@ BEGIN {
             }
             return wantarray ? keys %{ $self->{$stat} } : $self->{$stat};
         };
-## use critic
     }
     foreach my $stat (
         qw/cpustats pgswstats netstats netinfo diskstats diskusage processes/)
     {
-## no critic
         no strict 'refs';
         *{$stat} = sub {
             use strict 'refs';
@@ -267,7 +263,6 @@ BEGIN {
             return wantarray ? keys %{ $self->{$stat} } : $self->{$stat};
         };
     }
-## use critic
 }
 
 sub new {
@@ -359,7 +354,7 @@ sub search {
 sub psfind {
     my $self   = shift;
     my $filter = ref( $_[0] ) eq 'HASH' ? shift : {@_};
-    my $proc   = $self->{processes} or return;
+    my $proc   = $self->{processes} or return undef;
     my @hits   = ();
 
   PID: foreach my $pid ( keys %{$proc} ) {
@@ -428,7 +423,7 @@ sub _compare {
         croak ref($self) . ": bad search() / psfind() operator '$y'";
     }
 
-    return;
+    return undef;
 }
 
 1;
